@@ -30,7 +30,7 @@ sub generate_not {
 }
 
 no Mouse;
-__PACKAGE__->meta->make_immutable(strict_constructor => 1);
+__PACKAGE__->meta->make_immutable();
 
 __END__
 
